==> jbpm-distribution-6.2.0.CR2-bin-src-docs-examples.zip: org/jbpm/services/task/events/DefaultTaskEventListener.java <==
package org.jbpm.services.task.events;

import org.jbpm.services.task.lifecycle.listeners.TaskLifeCycleEventListener;
import org.kie.api.task.TaskEvent;

public class DefaultTaskEventListener implements TaskLifeCycleEventListener {

	@Override
	public void beforeTaskActivatedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskClaimedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskSkippedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskStartedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskStoppedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskCompletedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskFailedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskAddedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskExitedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskReleasedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskResumedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskSuspendedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskForwardedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskDelegatedEvent(TaskEvent event) {
		// intentionally left blank

	}
	
	@Override
	public void beforeTaskNominatedEvent(TaskEvent event) {
		// intentionally left blank
		
	}

	@Override
	public void afterTaskActivatedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskClaimedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskSkippedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskStartedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskStoppedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskCompletedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskFailedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskAddedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskExitedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskReleasedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskResumedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskSuspendedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskForwardedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskDelegatedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskNominatedEvent(TaskEvent event) {
		// intentionally left blank
		
	}

}

==> jbpm-distribution-6.3.0.CR2-bin-src-docs-examples.zip: org/jbpm/services/task/events/DefaultTaskEventListener.java <==
/*
 * Copyright 2015 JBoss Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
*/

package org.jbpm.services.task.events;


import org.kie.api.task.TaskEvent;
import org.kie.api.task.TaskLifeCycleEventListener;

public class DefaultTaskEventListener implements TaskLifeCycleEventListener {

	@Override
	public void beforeTaskActivatedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskClaimedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskSkippedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskStartedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskStoppedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskCompletedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskFailedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskAddedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskExitedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskReleasedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskResumedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskSuspendedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskForwardedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void beforeTaskDelegatedEvent(TaskEvent event) {
		// intentionally left blank

	}
	
	@Override
	public void beforeTaskNominatedEvent(TaskEvent event) {
		// intentionally left blank
		
	}

	@Override
	public void afterTaskActivatedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskClaimedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskSkippedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskStartedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskStoppedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskCompletedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskFailedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskAddedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskExitedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskReleasedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskResumedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskSuspendedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskForwardedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskDelegatedEvent(TaskEvent event) {
		// intentionally left blank

	}

	@Override
	public void afterTaskNominatedEvent(TaskEvent event) {
		// intentionally left blank
		
	}

}
